@@ -40,7 +40,12 @@
 #include "dialogs/event-editor.h"
 #include "dialogs/task-editor.h"
 
+#ifdef G_OS_WIN32
+const ECompEditorRegistry * const comp_editor_get_registry();
+#define comp_editor_registry comp_editor_get_registry()
+#else
 extern ECompEditorRegistry *comp_editor_registry;
+#endif
 
 
 
