@@ -230,19 +230,35 @@ bbdb_do_thread (const gchar *name, const gchar *email)
 static void
 walk_destinations_and_free (EDestination **dests)
 {
+	const gchar *name, *addr;
 	gint i;
 
 	if (!dests)
 		return;
 
 	for (i = 0; dests[i] != NULL; i++) {
-		const gchar *name, *addr;
+		if (e_destination_is_evolution_list (dests[i])) {
+			const GList *members;
 
-		name = e_destination_get_name (dests[i]);
-		addr = e_destination_get_email (dests[i]);
+			for (members = e_destination_list_get_dests (dests[i]); members; members = members->next) {
+				const EDestination *member = members->data;
 
-		if (name || addr)
-			bbdb_do_thread (name, addr);
+				if (!member)
+					continue;
+
+				name = e_destination_get_name (member);
+				addr = e_destination_get_email (member);
+
+				if (name || addr)
+					bbdb_do_thread (name, addr);
+			}
+		} else {
+			name = e_destination_get_name (dests[i]);
+			addr = e_destination_get_email (dests[i]);
+
+			if (name || addr)
+				bbdb_do_thread (name, addr);
+		}
 	}
 
 	e_destination_freev (dests);
@@ -275,7 +291,7 @@ bbdb_do_it (EBook *book, const gchar *name, const gchar *email)
 {
 	gchar *query_string, *delim, *temp_name = NULL;
 	EBookQuery *query;
-	GList *contacts, *l;
+	GList *contacts = NULL, *l;
 	EContact *contact;
 	gboolean status;
 	GError *error = NULL;
@@ -302,7 +318,7 @@ bbdb_do_it (EBook *book, const gchar *name, const gchar *email)
 	status = e_book_get_contacts (book, query, &contacts, NULL);
 	if (query)
 		e_book_query_unref (query);
-	if (contacts != NULL) {
+	if (contacts != NULL || !status) {
 		for (l = contacts; l != NULL; l = l->next)
 			g_object_unref ((GObject *)l->data);
 		g_list_free (contacts);
@@ -331,12 +347,12 @@ bbdb_do_it (EBook *book, const gchar *name, const gchar *email)
 	status = e_book_get_contacts (book, query, &contacts, NULL);
 	if (query)
 		e_book_query_unref (query);
-	if (contacts != NULL) {
+	if (contacts != NULL || !status) {
 
 		/* FIXME: If there's more than one contact with this
 		   name, just give up; we're not smart enough for
 		   this. */
-		if (contacts->next != NULL) {
+		if (!status || contacts->next != NULL) {
 			for (l = contacts; l != NULL; l = l->next)
 				g_object_unref ((GObject *)l->data);
 			g_list_free (contacts);
@@ -448,8 +464,6 @@ add_email_to_contact (EContact *contact, const gchar *email)
 	e_contact_set (contact, E_CONTACT_EMAIL, (gpointer) emails);
 }
 
-
-
 /* Code to implement the configuration user interface follows */
 
 static void
