@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -39,22 +39,21 @@
 #include "camel/camel-internet-address.h"
 #include "camel/camel-url.h"
 
-void org_gnome_copy_tool_copy_address(void *ep, EMPopupTargetURI *t);
+void org_gnome_copy_tool_copy_address(gpointer ep, EMPopupTargetURI *t);
 
 void
-org_gnome_copy_tool_copy_address(void *ep, EMPopupTargetURI *t)
+org_gnome_copy_tool_copy_address(gpointer ep, EMPopupTargetURI *t)
 {
 	if  (t->uri) {
 		CamelInternetAddress *cia = camel_internet_address_new();
 		CamelURL *curl;
 		GtkClipboard *clipboard;
-		char *addr;
-		const char *tmp;
+		gchar *addr;
+		const gchar *tmp;
 
 		curl = camel_url_new(t->uri, NULL);
-		camel_address_decode((CamelAddress *)cia, curl->path);
-		/* should it perhaps use address format? */
-		addr = camel_address_encode((CamelAddress *)cia);
+		camel_address_decode ((CamelAddress *) cia, curl->path);
+		addr = camel_address_format ((CamelAddress *) cia);
 		tmp = addr && addr[0] ? addr : t->uri + 7;
 
 		clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
