@@ -1,21 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * Authors: R.Raghavendran <raghavguru7@gmail.com>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		R.Raghavendran <raghavguru7@gmail.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, MA 02110-1301.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,7 +68,7 @@ struct _ExchangeSendOptionsDialogPrivate {
 	/*Label Widgets*/
 	GtkWidget *importance_label;
 	GtkWidget *sensitivity_label;
-	char *help_section;
+	gchar *help_section;
 };
 
 static void exchange_sendoptions_dialog_class_init (GObjectClass *object_class);
@@ -85,12 +87,12 @@ static guint signals[LAST_SIGNAL] = {0};
 /* exchange_send_options_get_widgets_data(ExchangeSendOptionsDialog *sod)
    Return Value:This function returns a -1 if an error occurs. In case of error-free operation a 1 is returned.
 */
-static int
+static gint
 exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 {
 	ExchangeSendOptionsDialogPrivate *priv;
 	ExchangeSendOptions *options;
-	const char *address, *email, *name;
+	const gchar *address, *email, *name;
 
 	guint count=0;
 	ENameSelectorEntry *name_selector_entry;
@@ -103,10 +105,10 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 	/* This block helps us fetch the address of the delegator(s). If no delegator is selected or more
 	   than one delegatee has been selected then an info dialog is popped up to help the user.
 	*/
-	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled))) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled))) {
 
 		name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
-		destination_store = e_name_selector_entry_peek_destination_store (E_NAME_SELECTOR_ENTRY 				                                               (name_selector_entry));
+		destination_store = e_name_selector_entry_peek_destination_store (E_NAME_SELECTOR_ENTRY									       (name_selector_entry));
 		destinations = e_destination_store_list_destinations (destination_store);
 		tmp = destinations;
 
@@ -118,8 +120,8 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 		   produced ambiguous results. Hence count is used :)
 		*/
 		for (; tmp != NULL; tmp = g_list_next (tmp)) {
-			address = g_strdup ((char *) e_destination_get_address (tmp->data));
-			email = g_strdup ((char *) e_destination_get_email (tmp->data));
+			address = g_strdup ((gchar *) e_destination_get_address (tmp->data));
+			email = g_strdup ((gchar *) e_destination_get_email (tmp->data));
 			name = g_strdup (e_destination_get_name (tmp->data));
 			if (g_str_equal (email, ""))
 				continue;
@@ -130,7 +132,7 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 			options->delegate_email = email;
 		}
 
-		if(count == 0) {
+		if (count == 0) {
 			e_error_run ((GtkWindow *) priv->main,
 				"org-gnome-exchange-operations:no-delegate-selected", NULL, NULL);
 			gtk_widget_grab_focus ((GtkWidget *) name_selector_entry);
@@ -140,7 +142,7 @@ exchange_send_options_get_widgets_data (ExchangeSendOptionsDialog *sod)
 			return -1;
 		}
 
-		if(count > 1) {
+		if (count > 1) {
 			e_error_run ((GtkWindow *)priv->main,
 				"org-gnome-exchange-operations:more-delegates-selected", NULL, NULL);
 			gtk_widget_grab_focus ((GtkWidget *) name_selector_entry);
@@ -220,7 +222,7 @@ exchange_send_options_fill_widgets_with_data (ExchangeSendOptionsDialog *sod)
 
 	name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
 
-	if(options->send_as_del_enabled) {
+	if (options->send_as_del_enabled) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled), TRUE);
 		gtk_widget_set_sensitive ((GtkWidget *)name_selector_entry, TRUE);
 		gtk_widget_set_sensitive ((GtkWidget *)priv->button_user, TRUE);
@@ -266,7 +268,7 @@ GType exchange_sendoptions_dialog_get_type (void)
       sizeof (ExchangeSendOptionsDialog),
      0,      /* n_preallocs */
      (GInstanceInitFunc) exchange_sendoptions_dialog_init,
- 	NULL    /* instance_init */
+	NULL    /* instance_init */
     };
     type = g_type_register_static (G_TYPE_OBJECT,
                                    "ExchangeSendOptionsDialogType",
@@ -277,26 +279,26 @@ GType exchange_sendoptions_dialog_get_type (void)
 
 static void exchange_send_options_cb (GtkDialog *dialog, gint state, gpointer func_data)
 {
-   	ExchangeSendOptionsDialogPrivate *priv;
-   	ExchangeSendOptionsDialog *sod;
+	ExchangeSendOptionsDialogPrivate *priv;
+	ExchangeSendOptionsDialog *sod;
 
 	sod = func_data;
         priv = sod->priv;
 
 	switch (state) {
 		case GTK_RESPONSE_OK:
-		     if(exchange_send_options_get_widgets_data (sod) < 0)
+		     if (exchange_send_options_get_widgets_data (sod) < 0)
 			return;
 		case GTK_RESPONSE_CANCEL:
-		    	gtk_widget_hide (priv->main);
-	    	    	gtk_widget_destroy (priv->main);
-	           	g_object_unref (priv->xml);
-	             	break;
+			gtk_widget_hide (priv->main);
+			gtk_widget_destroy (priv->main);
+			g_object_unref (priv->xml);
+			break;
 		case GTK_RESPONSE_HELP:
 			e_display_help (
 				GTK_WINDOW (priv->main),
 				priv->help_section);
-	    	    	break;
+			break;
 	}
 	g_signal_emit (G_OBJECT (func_data), signals[SOD_RESPONSE], 0, state);
 
@@ -319,7 +321,7 @@ delegate_option_toggled (GtkCheckButton *button, gpointer func_data)
 
 	name_selector_entry = e_name_selector_peek_section_entry (priv->proxy_name_selector, "Add User");
 
-	if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled))) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->delegate_enabled))) {
 		gtk_widget_set_sensitive ((GtkWidget *) name_selector_entry, TRUE);
 		gtk_widget_set_sensitive ((GtkWidget *) priv->button_user, TRUE);
 	}
@@ -409,7 +411,7 @@ exchange_sendoptions_dialog_run (ExchangeSendOptionsDialog *sod, GtkWidget *pare
 
 	exchange_send_options_fill_widgets_with_data (sod);
 
-	if(options->delegate_address) {
+	if (options->delegate_address) {
 		e_name_selector_model_peek_section (name_selector_model, "Add User", NULL, &destination_store);
 		des = e_destination_new ();
 		e_destination_set_email (des, options->delegate_email);
