@@ -484,7 +484,7 @@ can_support_actions (void)
 static void
 new_notify_status (EMEventTargetFolder *t)
 {
-	gchar *msg;
+	gchar *msg, *safetext;
 	gboolean new_icon = !status_icon;
 
 	if (new_icon) {
@@ -516,13 +516,14 @@ new_notify_status (EMEventTargetFolder *t)
 	#ifdef HAVE_LIBNOTIFY
 	/* Now check whether we're supposed to send notifications */
 	if (is_part_enabled (GCONF_KEY_STATUS_NOTIFICATION)) {
+		safetext = g_markup_escape_text(msg, strlen(msg));
 		if (notify) {
-			notify_notification_update (notify, _("New email"), msg, "mail-unread");
+			notify_notification_update (notify, _("New email"), safetext, "mail-unread");
 		} else {
 			if (!notify_init ("evolution-mail-notification"))
 				fprintf (stderr,"notify init error");
 
-			notify  = notify_notification_new (_("New email"), msg, "mail-unread", NULL);
+			notify  = notify_notification_new (_("New email"), safetext, "mail-unread", NULL);
 			notify_notification_attach_to_status_icon (notify, status_icon);
 
 			/* Check if actions are supported */
@@ -533,6 +534,7 @@ new_notify_status (EMEventTargetFolder *t)
 				g_timeout_add (500, notification_callback, notify);
 			}
 		}
+		g_free(safetext);
 	}
 	#endif
 
